Overview
========
This is an Infinidat project.

Installation
============
To install this package, use easy_install:

    easy_install -U infi.mount_utils

For development, clone this repository and run the following commands:

    easy_install -U infi.projector
    projector devenv build

Python 3
========
Python 3 support is experimental at this time.